<?php

namespace Litepie\Medium\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litepie\Medium\Http\Requests\MediaDetailCategoryRequest;
use Litepie\Medium\Interfaces\MediaDetailCategoryRepositoryInterface;
use Litepie\Medium\Models\MediaDetailCategory;

/**
 * Resource controller class for media_detail_category.
 */
class MediaDetailCategoryResourceController extends BaseController
{

    /**
     * Initialize media_detail_category resource controller.
     *
     * @param type MediaDetailCategoryRepositoryInterface $media_detail_category
     *
     * @return null
     */
    public function __construct(MediaDetailCategoryRepositoryInterface $media_detail_category)
    {
        parent::__construct();
        $this->repository = $media_detail_category;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litepie\Medium\Repositories\Criteria\MediaDetailCategoryResourceCriteria::class);
    }

    /**
     * Display a list of media_detail_category.
     *
     * @return Response
     */
    public function index(MediaDetailCategoryRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litepie\Medium\Repositories\Presenter\MediaDetailCategoryPresenter::class)
                ->$function();
        }

        $media_detail_categories = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('medium::media_detail_category.names'))
            ->view('medium::media_detail_category.index', true)
            ->data(compact('media_detail_categories', 'view'))
            ->output();
    }

    /**
     * Display media_detail_category.
     *
     * @param Request $request
     * @param Model   $media_detail_category
     *
     * @return Response
     */
    public function show(MediaDetailCategoryRequest $request, MediaDetailCategory $media_detail_category)
    {

        if ($media_detail_category->exists) {
            $view = 'medium::media_detail_category.show';
        } else {
            $view = 'medium::media_detail_category.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('medium::media_detail_category.name'))
            ->data(compact('media_detail_category'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new media_detail_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(MediaDetailCategoryRequest $request)
    {

        $media_detail_category = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('medium::media_detail_category.name')) 
            ->view('medium::media_detail_category.create', true) 
            ->data(compact('media_detail_category'))
            ->output();
    }

    /**
     * Create new media_detail_category.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(MediaDetailCategoryRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $media_detail_category                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('medium::media_detail_category.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('medium/media_detail_category/' . $media_detail_category->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/medium/media_detail_category'))
                ->redirect();
        }

    }

    /**
     * Show media_detail_category for editing.
     *
     * @param Request $request
     * @param Model   $media_detail_category
     *
     * @return Response
     */
    public function edit(MediaDetailCategoryRequest $request, MediaDetailCategory $media_detail_category)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('medium::media_detail_category.name'))
            ->view('medium::media_detail_category.edit', true)
            ->data(compact('media_detail_category'))
            ->output();
    }

    /**
     * Update the media_detail_category.
     *
     * @param Request $request
     * @param Model   $media_detail_category
     *
     * @return Response
     */
    public function update(MediaDetailCategoryRequest $request, MediaDetailCategory $media_detail_category)
    {
        try {
            $attributes = $request->all();

            $media_detail_category->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('medium::media_detail_category.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('medium/media_detail_category/' . $media_detail_category->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('medium/media_detail_category/' . $media_detail_category->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the media_detail_category.
     *
     * @param Model   $media_detail_category
     *
     * @return Response
     */
    public function destroy(MediaDetailCategoryRequest $request, MediaDetailCategory $media_detail_category)
    {
        try {

            $media_detail_category->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('medium::media_detail_category.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('medium/media_detail_category/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('medium/media_detail_category/' . $media_detail_category->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple media_detail_category.
     *
     * @param Model   $media_detail_category
     *
     * @return Response
     */
    public function delete(MediaDetailCategoryRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('medium::media_detail_category.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('medium/media_detail_category'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/medium/media_detail_category'))
                ->redirect();
        }

    }

    /**
     * Restore deleted media_detail_categories.
     *
     * @param Model   $media_detail_category
     *
     * @return Response
     */
    public function restore(MediaDetailCategoryRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('medium::media_detail_category.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/medium/media_detail_category'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/medium/media_detail_category/'))
                ->redirect();
        }

    }

}
